function [ru,recpulse,Erecpulse,slevbin,slevbin_preamble]=usersig(modulation,levels,pulse,h,bseq,pnseq,dt,Tc,Nlev,pnseq_preamble,bseq_preamble)
%
% [ru,recpulse,Erecpulse,slevbin,slevbin_preamble]=usersig(modulation,levels,pulse,h,bseq,pnseq,dt,Tc,Nlev,pnseq_preamble,bseq_preamble)
%
% Signal of a single user --> ru
%
% modulation = 1 --> PPM, 2 --> PAM
% levels = modulation levels
% pulse
% h
% bseq = input bit sequence
% pnseq = level sequence
% dt
% Tc = chip time
% Nlev = # of levels
% pnseq_preamble = level sequence dedicated to preamble (not modulated !)
%                  where pnseq_preamble < 0 --> no pulse transmission (guard time)
%
% Es:
% [ru_est,recpulse_est,Erecpulse_est,slevbin_est,slevbin_preamble_est]=usersig(modulation,levels,pulse,[1],[],[],dt,Tc,Nlev,pnseq_preamble);

if (nargin==9)
    pnseq_preamble=[];
    bseq_preamble=[];
end
if (nargin==10)
    bseq_preamble=[];
end

Noversample=round(Tc/dt);
recpulse=conv(pulse,h);
Erecpulse=recpulse*recpulse'*dt;
%
% transmitted bits --> levels
slev=[];
samp=[];
for ii=1:length(bseq)
    if (modulation==1)
        % PPM
        % samp=[samp,ones(1,length(pnseq))];
        samp=[samp,sign(pnseq)];
        if (bseq(ii)==0)
            slev=[slev,abs(pnseq)+levels(1)];
        else
            slev=[slev,abs(pnseq)+levels(2)];
        end
    end
    if (modulation==2)
        % PAM
        slev=[slev,abs(pnseq)];
        if (bseq(ii)==0)
            % samp=[samp,levels(1)*ones(1,length(pnseq))];
            samp=[samp,levels(1)*sign(pnseq)];
        else
            % samp=[samp,levels(2)*ones(1,length(pnseq))];
            samp=[samp,levels(2)*sign(pnseq)];
        end
    end
end
   
% add preamble
slev=[pnseq_preamble,slev];
samp=[ones(1,length(pnseq_preamble)),samp];

% levels
sch=[];
slevbin=[];
for ii=1:length(slev)
    if (slev(ii)>=0)
        sch=[sch,zeros(1,Noversample*slev(ii)),samp(ii),zeros(1,(Nlev-slev(ii)-1)*Noversample+Noversample-1)];
    else
        sch=[sch,zeros(1,Noversample*Nlev)];
    end
end
for ii=1:length(pnseq)
    slevbin=[slevbin,zeros(1,abs(pnseq(ii))),sign(pnseq(ii)),zeros(1,Nlev-abs(pnseq(ii))-1)];
end
slevbin_preamble=[];
for ii=1:length(pnseq_preamble)
    if (slev(ii)>=0)
        slevbin_preamble=[slevbin_preamble,zeros(1,pnseq_preamble(ii)),1,zeros(1,Nlev-pnseq_preamble(ii)-1)];
    else
        slevbin_preamble=[slevbin_preamble,zeros(1,Nlev)];
    end    
end

% signal
ru=conv(sch,recpulse);
